@@ -1,7 +1,7 @@
 #ifndef PHP_SNUFFLEUPAGUS_H
 #define PHP_SNUFFLEUPAGUS_H
 
-#define PHP_SNUFFLEUPAGUS_VERSION "0.12.0"
+#define PHP_SNUFFLEUPAGUS_VERSION "0.13.0"
 #define PHP_SNUFFLEUPAGUS_EXTNAME "snuffleupagus"
 #define PHP_SNUFFLEUPAGUS_AUTHOR "NBS System & Julien (jvoisin) Voisin & SektionEins GmbH"
 #define PHP_SNUFFLEUPAGUS_URL "https://github.com/jvoisin/snuffleupagus"
@@ -141,7 +141,7 @@ sp_config_eval config_eval;
 sp_config_wrapper config_wrapper;
 sp_config_session config_session;
 sp_config_ini config_ini;
-char config_log_media;
+sp_config_log config_log_media;
 int config_log_max_len;
 u_long config_max_execution_depth;
 bool config_server_encode;
